@@ -4,7 +4,7 @@ use Any::Moose;
 use Any::Moose (
     '::Util' => [qw/apply_all_roles/],
 );
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Carp ();
 
@@ -61,11 +61,7 @@ sub import {
 
     init_class($caller);
 
-    if (Any::Moose::moose_is_preferred()) {
-        Moose->import({ into_level => 1 });
-    } else {
-        Mouse->export_to_level( 1 );
-    }
+    any_moose()->import({ into_level => 1 });
 
     no strict 'refs';
     *{"$caller\::__MIDDLEWARE__"} = sub {
